StorageBase class abstract

An abstract class that defines the interface for persistent data storage.

This class provides a common API for reading and writing data as a Uint8List, allowing kaeru_store to work with various storage mechanisms (e.g., local file system, localStorage on the web) consistently.

To create a custom storage provider, implement this class and provide the logic for the get and set methods.

Implementers

Constructors

StorageBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String path) → Future<Uint8List>
Reads and returns the data from a path as a Uint8List.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String path, Uint8List data) → Future<void>
Writes a byte array data to a specific path.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited