get abstract method

Future<Uint8List> get(
  1. String path
)

Reads and returns the data from a path as a Uint8List.

If the file does not exist, an empty Uint8List should be returned.

Implementation

Future<Uint8List> get(String path);