set abstract method

Future<void> set(
  1. String path,
  2. Uint8List data
)

Writes a byte array data to a specific path.

If the path or its parent directories do not exist, they should be created.

Implementation

Future<void> set(String path, Uint8List data);