StorageDefault class

The default implementation of StorageBase for the web platform.

This class uses window.localStorage to persist data in the user's browser.

The Uint8List data is Base64 encoded before being stored and is decoded upon retrieval. The {document} string in the path is replaced with document to create the key for localStorage.

Implemented types

Constructors

StorageDefault()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String path) Future<Uint8List>
Reads and returns the data from a path as a Uint8List.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String path, Uint8List buffer) Future<void>
Writes a byte array data to a specific path.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited