set method

  1. @override
Future<void> set(
  1. String path,
  2. Uint8List buffer
)
override

Writes a byte array data to a specific path.

If the path or its parent directories do not exist, they should be created.

Implementation

@override
Future<void> set(String path, Uint8List buffer) async {
  final key = path.replaceFirst('{document}', 'document');
  final value = base64Encode(buffer);

  _localStorage.setItem(key, value);
}