id property
String
get
id
A unique ID for the store. This value is used to create the storage filename, so it must be unique among all stores.
Implementation
String get id;
A unique ID for the store. This value is used to create the storage filename, so it must be unique among all stores.
String get id;