privateKey property
The global password used to encrypt data for all stores. If left empty, encryption is disabled.
Implementation
static String privateKey = '';
The global password used to encrypt data for all stores. If left empty, encryption is disabled.
static String privateKey = '';