storageScope property
The storage instance specific to this store. By default, it uses the global Store.storage. Override this getter to provide a different storage mechanism.
Implementation
@protected
StorageBase get storageScope => storage;
The storage instance specific to this store. By default, it uses the global Store.storage. Override this getter to provide a different storage mechanism.
@protected
StorageBase get storageScope => storage;