encrypt library

Functions

decryptWithPassword(Uint8List data, String password, String salt) Future
Decrypts the data using the provided password and salt.
deriveKey(String password, String salt, {int length = 32, int iterations = 100000}) Uint8List
Derives an AES key from a password and salt using the PBKDF2 algorithm.
encryptWithPassword(dynamic plainText, String password, String salt) Future<Uint8List>
Encrypts the plainText with the given password and salt using AES-CBC.