StorageDefault class
The default IO implementation of StorageBase for mobile and desktop platforms.
This class uses dart:io and path_provider to read and write data
to the device's local file system.
The file path is processed to replace the {document} string with the actual
path to the application's documents directory.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String path) → Future< Uint8List> -
Reads and returns the data from a
pathas aUint8List.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
set(
String path, Uint8List buffer) → Future< void> -
Writes a byte array
datato a specificpath.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited