Reads and returns the data from a path as a Uint8List.
path
Uint8List
If the file does not exist, an empty Uint8List should be returned.
@override Future<Uint8List> get(String path) async { throw UnimplementedError(); }