set method
Writes a byte array data to a specific path.
If the path or its parent directories do not exist, they should be created.
Implementation
@override
Future<void> set(String path, Uint8List buffer) async {
final key = path.replaceFirst('{document}', 'document');
final value = base64Encode(buffer);
_localStorage.setItem(key, value);
}