persistents method
Returns a list of Ref variables that should be persisted.
The order of the Refs in this list is important and should not be
changed after data has been saved, as it affects how data is restored.
Implementation
@protected
List<Ref> persistents() => const <Ref>[];