restoring property
A Future that completes when the initial data restoration is finished.
This is null if there is nothing to restore or after the restoration
is complete. You can await on Store.preload() to wait for multiple stores.
Implementation
Future<void>? restoring;